summaryrefslogtreecommitdiffstatshomepage
diff options
context:
space:
mode:
author Brian Troha <briantro@users.noreply.github.com>2008-10-19 17:33:01 +0000
committer Brian Troha <briantro@users.noreply.github.com>2008-10-19 17:33:01 +0000
commit430c387dceb026b6b7bf35f7abafca1da4dd99ca (patch)
tree66bc5d4157424ac9d5a27043f512e3dacf203860
parent9014e91a6295fc23e4ff97ac5737e067e66d3258 (diff)
new clones added:
New clones added ---------------- Police Trainer (v1.3B Newer) [Brian Troha] Egg Venture (Release 8) [Brian Troha] Kick for the Goal [Brian Troha] (Not Working)
-rw-r--r--src/mame/drivers/lethalj.c27
-rw-r--r--src/mame/drivers/m107.c77
-rw-r--r--src/mame/drivers/policetr.c61
-rw-r--r--src/mame/machine/irem_cpu.c2
-rw-r--r--src/mame/mamedriv.c3
5 files changed, 129 insertions, 41 deletions
diff --git a/src/mame/drivers/lethalj.c b/src/mame/drivers/lethalj.c
index 3c436f8983e..43f4bea0703 100644
--- a/src/mame/drivers/lethalj.c
+++ b/src/mame/drivers/lethalj.c
@@ -700,6 +700,32 @@ ROM_START( eggventr )
ROM_END
+ROM_START( eggvent8 )
+ ROM_REGION16_LE( 0x100000, "user1", 0 ) /* 34010 code */
+ ROM_LOAD16_BYTE( "eggvc8.8", 0x000000, 0x020000, CRC(5a130c04) SHA1(00408912b436efa003bb02dce90fae4fe33a0180) )
+ ROM_LOAD16_BYTE( "eggvc9.8", 0x000001, 0x020000, CRC(3ac0a95b) SHA1(7f3bd0e6d2d790af4aa6881ea8de8b296a64164a) )
+ ROM_COPY( "user1", 0x000000, 0x040000, 0x040000 )
+ ROM_COPY( "user1", 0x000000, 0x080000, 0x080000 )
+
+ ROM_REGION16_LE( 0x600000, "gfx1", 0 ) /* graphics data */
+ ROM_LOAD16_BYTE( "egr1.bin", 0x000000, 0x100000, CRC(f73f80d9) SHA1(6278b45579a256b9576ba6d4f5a15fab26797c3d) )
+ ROM_LOAD16_BYTE( "egr2.bin", 0x000001, 0x100000, CRC(3a9ba910) SHA1(465aa3119af103aa65b25042b3572fdcb9c1887a) )
+ ROM_LOAD16_BYTE( "egr4.bin", 0x200000, 0x100000, CRC(4ea5900e) SHA1(20341337ee3c6c22580c52312156b818f4187693) )
+ ROM_LOAD16_BYTE( "egr3.bin", 0x200001, 0x100000, CRC(3f8dfc73) SHA1(83a168069f896ea7e67a97c6d591d09b19d5f486) )
+ ROM_LOAD16_BYTE( "egr6.3", 0x400000, 0x100000, CRC(f299d818) SHA1(abbb333c43675d34c59201b5d297779cfea8b092) )
+ ROM_LOAD16_BYTE( "egr5.3", 0x400001, 0x100000, CRC(ebfca07b) SHA1(20465d14b41d99651166f221057737d7b3cc770c) )
+
+ ROM_REGION( 0x40000, "oki1", 0 ) /* sound data */
+ ROM_LOAD( "eu20.bin", 0x00000, 0x40000, CRC(3760b1db) SHA1(70e258a6036f9ce26b354c4df57e0e4d2c871bcb) )
+
+ ROM_REGION( 0x40000, "oki2", 0 ) /* sound data */
+ ROM_LOAD( "eu21.bin", 0x00000, 0x40000, CRC(3760b1db) SHA1(70e258a6036f9ce26b354c4df57e0e4d2c871bcb) )
+
+ ROM_REGION( 0x40000, "oki3", 0 ) /* sound data */
+ ROM_LOAD( "eu18.bin", 0x00000, 0x40000, CRC(3760b1db) SHA1(70e258a6036f9ce26b354c4df57e0e4d2c871bcb) )
+ROM_END
+
+
ROM_START( eggvent7 )
ROM_REGION16_LE( 0x100000, "user1", 0 ) /* 34010 code */
ROM_LOAD16_BYTE( "eggvc8.7", 0x000000, 0x020000, CRC(99999899) SHA1(e3908600fa711baa7f7562f86498ec7e988a5bea) )
@@ -907,6 +933,7 @@ static DRIVER_INIT( cclownz )
GAME( 1996, lethalj, 0, lethalj, lethalj, 0, ROT0, "The Game Room", "Lethal Justice", 0 )
GAME( 1997, eggventr, 0, gameroom, eggventr, 0, ROT0, "The Game Room", "Egg Venture (Release 10)", 0 )
+GAME( 1997, eggvent8, eggventr, gameroom, eggventr, 0, ROT0, "The Game Room", "Egg Venture (Release 8)", 0 )
GAME( 1997, eggvent7, eggventr, gameroom, eggventr, 0, ROT0, "The Game Room", "Egg Venture (Release 7)", 0 )
GAME( 1997, eggventa, eggventr, gameroom, eggventr, 0, ROT0, "The Game Room (Allied Leisure license)", "Egg Venture (A.L. Release)", 0 )
GAME( 1997, eggvntdx, eggventr, gameroom, eggvntdx, 0, ROT0, "The Game Room", "Egg Venture Deluxe", 0 )
diff --git a/src/mame/drivers/m107.c b/src/mame/drivers/m107.c
index 687c13ffd3a..baf7a997a26 100644
--- a/src/mame/drivers/m107.c
+++ b/src/mame/drivers/m107.c
@@ -4,6 +4,7 @@
Fire Barrel (c) 1993 Irem Corporation
Dream Soccer '94 (c) 1994 Data East Corporation
+ Kick for the Goal (c) 1994 Jaleco
World PK Soccer (c) 1995 Jaleco
@@ -12,6 +13,9 @@
Emulation by Bryan McPhail, mish@tendril.co.uk
+To Do:
+ Hook up EEPROM in Kick for the Goal / World PK Soccer
+
2008-08
Dip locations have been added assuming that the layout is the same as the
m92 boards (and earlier Irem boards). However, it would be nice to have them
@@ -561,31 +565,63 @@ ROM_END
ROM_START( wpksoc )
ROM_REGION( 0x180000, "main", 0 ) /* v30 main cpu */
- ROM_LOAD16_BYTE( "pkeurd.h0", 0x000001, 0x040000, CRC(b4917788) SHA1(673294c518eaf28354fa6a3058f9325c6d9ddde6) )
- ROM_LOAD16_BYTE( "pkeurd.l0", 0x000000, 0x040000, CRC(03816bae) SHA1(832e2ec722b41d41626fec583fc11e9ff62cdaa0) )
+ ROM_LOAD16_BYTE( "pk-h0-eur-d.h0", 0x000001, 0x040000, CRC(b4917788) SHA1(673294c518eaf28354fa6a3058f9325c6d9ddde6) )
+ ROM_LOAD16_BYTE( "pk-l0-eur-d.l0", 0x000000, 0x040000, CRC(03816bae) SHA1(832e2ec722b41d41626fec583fc11e9ff62cdaa0) )
ROM_REGION( 0x100000, "sound", 0 )
- ROM_LOAD16_BYTE( "pkos.sh0", 0x000001, 0x010000, CRC(1145998c) SHA1(cdb2a428e0f35302b81696dab02d3dd2c433f6e5) )
- ROM_LOAD16_BYTE( "pkos.sl0", 0x000000, 0x010000, CRC(542ee1c7) SHA1(b934adeecbba17cf96b06a2b1dc1ceaebdf9ad10) )
+ ROM_LOAD16_BYTE( "pk-sh0.sh0", 0x000001, 0x010000, CRC(1145998c) SHA1(cdb2a428e0f35302b81696dab02d3dd2c433f6e5) )
+ ROM_LOAD16_BYTE( "pk-sl0.sl0", 0x000000, 0x010000, CRC(542ee1c7) SHA1(b934adeecbba17cf96b06a2b1dc1ceaebdf9ad10) )
ROM_REGION( 0x200000, "gfx1", ROMREGION_DISPOSE ) /* chars */
- ROM_LOAD16_BYTE( "pkos.c00", 0x000000, 0x80000, CRC(42ae3d73) SHA1(e4777066155c9882695ebff0412bd879b8d6f716) )
- ROM_LOAD16_BYTE( "pkos.c10", 0x000001, 0x80000, CRC(86acf45c) SHA1(3b3d2abcf8000161a37d5e2619df529533aea47d) )
- ROM_LOAD16_BYTE( "pkos.c01", 0x100000, 0x80000, CRC(b0d33f87) SHA1(f2c0e3a10615c6861a3f6fd82a3f066e8e264233) )
- ROM_LOAD16_BYTE( "pkos.c11", 0x100001, 0x80000, CRC(19de7d63) SHA1(6d0633e412b47accaecc887a5c39f542eda49e81) )
+ ROM_LOAD16_BYTE( "pk-c00-os.c00", 0x000000, 0x80000, CRC(42ae3d73) SHA1(e4777066155c9882695ebff0412bd879b8d6f716) )
+ ROM_LOAD16_BYTE( "pk-c10-os.c10", 0x000001, 0x80000, CRC(86acf45c) SHA1(3b3d2abcf8000161a37d5e2619df529533aea47d) )
+ ROM_LOAD16_BYTE( "pk-c01-os.c01", 0x100000, 0x80000, CRC(b0d33f87) SHA1(f2c0e3a10615c6861a3f6fd82a3f066e8e264233) )
+ ROM_LOAD16_BYTE( "pk-c11-os.c11", 0x100001, 0x80000, CRC(19de7d63) SHA1(6d0633e412b47accaecc887a5c39f542eda49e81) )
ROM_REGION( 0x400000, "gfx2", ROMREGION_DISPOSE ) /* sprites */
- ROM_LOAD16_BYTE( "pk.000", 0x000000, 0x80000, CRC(165ce027) SHA1(3510b323c683ade4dd7307b539072bb342b6796d) )
- ROM_LOAD16_BYTE( "pk.001", 0x000001, 0x80000, CRC(e2745147) SHA1(99026525449c2ca84e054a7d633c400e0e836461) )
- ROM_LOAD16_BYTE( "pk.010", 0x100000, 0x80000, CRC(6c171b73) SHA1(a99c9f012f21373daea08d28554cc36170f4e1fa) )
- ROM_LOAD16_BYTE( "pk.011", 0x100001, 0x80000, CRC(471c0bf4) SHA1(1cace5ffd5db91850662de929cb9086dc154d662) )
- ROM_LOAD16_BYTE( "pk.020", 0x200000, 0x80000, CRC(c886dad1) SHA1(9b58a2f108547c3f55399932a7e56031c5658737) )
- ROM_LOAD16_BYTE( "pk.021", 0x200001, 0x80000, CRC(91e877ff) SHA1(3df095632728ab16ab229d592ab12d3df44b2629) )
- ROM_LOAD16_BYTE( "pk.030", 0x300000, 0x80000, CRC(3390621c) SHA1(4138c690666f78b1c5cf83d815ed6b37239a94b4) )
- ROM_LOAD16_BYTE( "pk.031", 0x300001, 0x80000, CRC(4d322804) SHA1(b5e2b40e3ce83b6f97b2b57edaa79df6968d0997) )
+ ROM_LOAD16_BYTE( "pk-000.000", 0x000000, 0x80000, CRC(165ce027) SHA1(3510b323c683ade4dd7307b539072bb342b6796d) )
+ ROM_LOAD16_BYTE( "pk-001.001", 0x000001, 0x80000, CRC(e2745147) SHA1(99026525449c2ca84e054a7d633c400e0e836461) )
+ ROM_LOAD16_BYTE( "pk-010.010", 0x100000, 0x80000, CRC(6c171b73) SHA1(a99c9f012f21373daea08d28554cc36170f4e1fa) )
+ ROM_LOAD16_BYTE( "pk-011.011", 0x100001, 0x80000, CRC(471c0bf4) SHA1(1cace5ffd5db91850662de929cb9086dc154d662) )
+ ROM_LOAD16_BYTE( "pk-020.020", 0x200000, 0x80000, CRC(c886dad1) SHA1(9b58a2f108547c3f55399932a7e56031c5658737) )
+ ROM_LOAD16_BYTE( "pk-021.021", 0x200001, 0x80000, CRC(91e877ff) SHA1(3df095632728ab16ab229d592ab12d3df44b2629) )
+ ROM_LOAD16_BYTE( "pk-030.030", 0x300000, 0x80000, CRC(3390621c) SHA1(4138c690666f78b1c5cf83d815ed6b37239a94b4) )
+ ROM_LOAD16_BYTE( "pk-031.031", 0x300001, 0x80000, CRC(4d322804) SHA1(b5e2b40e3ce83b6f97b2b57edaa79df6968d0997) )
ROM_REGION( 0x100000, "irem", 0 ) /* ADPCM samples */
- ROM_LOAD( "pk.da0", 0x000000, 0x80000, CRC(26a34cf4) SHA1(a8a7cd91cdc6d644ee02ca16e7fdc8debf8f3a5f) )
+ ROM_LOAD( "pk-da0.da0", 0x000000, 0x80000, CRC(26a34cf4) SHA1(a8a7cd91cdc6d644ee02ca16e7fdc8debf8f3a5f) )
+ROM_END
+
+ROM_START( kftgoal )
+ ROM_REGION( 0x180000, "main", 0 ) /* v30 main cpu */
+ ROM_LOAD16_BYTE( "pk-h0-usa-d.h0", 0x000001, 0x040000, CRC(aed4cde0) SHA1(2fe04bf93c353108b82a0b6017229e9b0f451b06) )
+ ROM_LOAD16_BYTE( "pk-l0-usa-d.l0", 0x000000, 0x040000, CRC(39fe30d2) SHA1(e0c117da4fe9c779dd534ee0d09685aeb5f579c6) )
+
+ ROM_REGION( 0x100000, "sound", 0 )
+ ROM_LOAD16_BYTE( "pk-sh0.sh0", 0x000001, 0x010000, CRC(1145998c) SHA1(cdb2a428e0f35302b81696dab02d3dd2c433f6e5) )
+ ROM_LOAD16_BYTE( "pk-sl0.sl0", 0x000000, 0x010000, CRC(542ee1c7) SHA1(b934adeecbba17cf96b06a2b1dc1ceaebdf9ad10) )
+
+ ROM_REGION( 0x200000, "gfx1", ROMREGION_DISPOSE ) /* chars */
+ ROM_LOAD16_BYTE( "pk-c00-os.c00", 0x000000, 0x80000, CRC(42ae3d73) SHA1(e4777066155c9882695ebff0412bd879b8d6f716) )
+ ROM_LOAD16_BYTE( "pk-c10-os.c10", 0x000001, 0x80000, CRC(86acf45c) SHA1(3b3d2abcf8000161a37d5e2619df529533aea47d) )
+ ROM_LOAD16_BYTE( "pk-c01-os.c01", 0x100000, 0x80000, CRC(b0d33f87) SHA1(f2c0e3a10615c6861a3f6fd82a3f066e8e264233) )
+ ROM_LOAD16_BYTE( "pk-c11-os.c11", 0x100001, 0x80000, CRC(19de7d63) SHA1(6d0633e412b47accaecc887a5c39f542eda49e81) )
+
+ ROM_REGION( 0x400000, "gfx2", ROMREGION_DISPOSE ) /* sprites */
+ ROM_LOAD16_BYTE( "pk-000-usa.000", 0x000000, 0x80000, CRC(72e905ab) SHA1(5f47f0db0a19311cb74c39ea9d86f6909b926aa8) )
+ ROM_LOAD16_BYTE( "pk-001-usa.001", 0x000001, 0x80000, CRC(eec4f43c) SHA1(93133389701c8752fc288f3f82da2646446804ca) )
+ ROM_LOAD16_BYTE( "pk-010-usa.010", 0x100000, 0x80000, CRC(b3339d73) SHA1(1f59591a24434cf7d754d211c1a20591c1d7234c) )
+ ROM_LOAD16_BYTE( "pk-011-usa.011", 0x100001, 0x80000, CRC(bab2b7cf) SHA1(53997c5dc204a4f510624dcdef949e859ad79d23) )
+ ROM_LOAD16_BYTE( "pk-020-usa.020", 0x200000, 0x80000, CRC(740a0bef) SHA1(89782d6d76e0cbd99047dc9a4d3c00bbab0d6bce) )
+ ROM_LOAD16_BYTE( "pk-021-usa.021", 0x200001, 0x80000, CRC(f44208a6) SHA1(e6436bacebca786de1521ce7a207aca686e312a0) )
+ ROM_LOAD16_BYTE( "pk-030-usa.030", 0x300000, 0x80000, CRC(8eceef50) SHA1(e39a2420a6259a8571a71fd3f9b003b0e0abea3b) )
+ ROM_LOAD16_BYTE( "pk-031-usa.031", 0x300001, 0x80000, CRC(8aa7dc04) SHA1(8aebdf50a832acf00fcfebb35ab49a06d13bc444) )
+
+ ROM_REGION( 0x100000, "irem", 0 ) /* ADPCM samples */
+ ROM_LOAD( "pk-da0.da0", 0x000000, 0x80000, CRC(26a34cf4) SHA1(a8a7cd91cdc6d644ee02ca16e7fdc8debf8f3a5f) )
+
+ ROM_REGION( 0x2000, "user1", 0 ) /* ST M28C64C-20PI Eeprom */
+ ROM_LOAD( "st-m28c64c.eeprom", 0x000, 0x2000, CRC(8e0c8b7c) SHA1(0b57290d709e6d54ce1bb3a5c01b80590203c1dd) )
ROM_END
/***************************************************************************/
@@ -635,6 +671,7 @@ static DRIVER_INIT( wpksoc )
/***************************************************************************/
-GAME( 1993, firebarr, 0, firebarr, firebarr, firebarr, ROT270, "Irem", "Fire Barrel (Japan)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS )
-GAME( 1994, dsoccr94, 0, dsoccr94, dsoccr94, dsoccr94, ROT0, "Irem (Data East Corporation license)", "Dream Soccer '94", 0 )
-GAME( 1995, wpksoc, 0, wpksoc, wpksoc, wpksoc, ROT0, "Jaleco", "World PK Soccer", GAME_NOT_WORKING | GAME_IMPERFECT_GRAPHICS )
+GAME( 1993, firebarr, 0, firebarr, firebarr, firebarr, ROT270, "Irem", "Fire Barrel (Japan)", GAME_IMPERFECT_SOUND | GAME_IMPERFECT_GRAPHICS )
+GAME( 1994, dsoccr94, 0, dsoccr94, dsoccr94, dsoccr94, ROT0, "Irem (Data East Corporation license)", "Dream Soccer '94", 0 )
+GAME( 1995, wpksoc, 0, wpksoc, wpksoc, wpksoc, ROT0, "Jaleco", "World PK Soccer", GAME_NOT_WORKING | GAME_IMPERFECT_GRAPHICS )
+GAME( 1994, kftgoal, wpksoc, wpksoc, wpksoc, wpksoc, ROT0, "Jaleco", "Kick for the Goal", GAME_NOT_WORKING | GAME_IMPERFECT_GRAPHICS )
diff --git a/src/mame/machine/irem_cpu.c b/src/mame/machine/irem_cpu.c
index ece16e2adb9..2b1db8bfe68 100644
--- a/src/mame/machine/irem_cpu.c
+++ b/src/mame/machine/irem_cpu.c
@@ -26,7 +26,7 @@
In The Hunt Irem D8000011A1 020
Risky Challenge/Gussun Oyoyo Irem D8000019A1 022 9331NK700
Match It II/Shisensho II Irem D8000020A1 023 9320NK700
- World PK Soccer Irem D8000021A1
+ World PK Soccer/Kick for the Goal Irem D8000021A1 024 9335NK701
Ninja Baseball Batman Irem D8000021A1 024 9335NK700
Perfect Soldiers Irem D8000022A1
Dream Soccer '94 Irem D8000023A1 026
diff --git a/src/mame/mamedriv.c b/src/mame/mamedriv.c
index 5f6465a7184..6392b852735 100644
--- a/src/mame/mamedriv.c
+++ b/src/mame/mamedriv.c
@@ -1490,6 +1490,7 @@ const game_driver * const drivers[] =
/* M107 */
DRIVER( firebarr ) /* (c) 1993 Irem (Japan) */
DRIVER( dsoccr94 ) /* (c) 1994 Irem (Data East Corporation license) */
+ DRIVER( kftgoal ) /* (c) 1994 Jaleco */
DRIVER( wpksoc ) /* (c) 1995 Jaleco */
/* Gottlieb/Mylstar games (Gottlieb became Mylstar in 1983) */
@@ -7750,6 +7751,7 @@ Other Sun games
DRIVER( policetr ) /* (c) 1996 P&P Marketing */
DRIVER( polict11 ) /* (c) 1996 P&P Marketing */
DRIVER( polict10 ) /* (c) 1996 P&P Marketing */
+ DRIVER( plctr13a ) /* (c) 1996 P&P Marketing */
DRIVER( plctr13b ) /* (c) 1996 P&P Marketing */
DRIVER( sshooter ) /* (c) 1998 P&P Marketing */
DRIVER( sshoot12 ) /* (c) 1998 P&P Marketing */
@@ -7859,6 +7861,7 @@ Other Sun games
DRIVER( skyarmy ) /* (c) 1982 Shoei */
DRIVER( lethalj ) /* (c) 1996 The Game Room */
DRIVER( eggventr ) /* (c) 1997 The Game Room */
+ DRIVER( eggvent8 ) /* (c) 1997 The Game Room */
DRIVER( eggvent7 ) /* (c) 1997 The Game Room */
DRIVER( eggventa ) /* (c) 1997 The Game Room (Allied Leisure license) */
DRIVER( eggvntdx ) /* (c) 1997 The Game Room */
diff --git a/src/mame/drivers/policetr.c b/src/mame/drivers/policetr.c
index 03b478c00ee..d8cd9483533 100644
--- a/src/mame/drivers/policetr.c
+++ b/src/mame/drivers/policetr.c
@@ -13,8 +13,8 @@
Note: Police Trainer v1.3B runs on the same revision PCB as Sharpshooter - Rev 0.5B
If you hold the test button down and boot the game, all program roms
- fail the checksum. However, each checksum listed matches the checksum
- printed on the ROM label. This has been verified on an original PCB.
+ fail the checksum. This has been verified on an original PCB.
+ See below for specific information on each set.
Note: Police Trainer v1.0 (Rev 0.2 PCB), the checksum results in MAME have been
verified to be the same as an original PCB.
@@ -557,36 +557,56 @@ ROM_START( polict10 ) /* Rev 0.2 PCB with all chips dated 10/07/96 */
ROM_END
-ROM_START( plctr13b ) /* Rev 0.5B PCB , unknown program rom date */
+ROM_START( plctr13a ) /* Rev 0.5B PCB , unknown program rom date. Actual version is V1.3B */
ROM_REGION( 0x400000, "gfx1", ROMREGION_ERASE00 )
ROM_LOAD16_BYTE( "pt-u121.bin", 0x000000, 0x100000, CRC(56b0b00a) SHA1(4034fe373a61f756f4813f0c20b1cf05e4338059) )
ROM_LOAD16_BYTE( "pt-u120.bin", 0x000001, 0x100000, CRC(ca664142) SHA1(2727ecb9287b4ed30088e017bb6b8763dfb75b2f) )
ROM_LOAD16_BYTE( "pt-u125.bin", 0x200000, 0x100000, CRC(e9ccf3a0) SHA1(b3fd8c094f76ace4cf403c3d0f6bd6c5d8db7d6a) )
ROM_LOAD16_BYTE( "pt-u124.bin", 0x200001, 0x100000, CRC(f4acf921) SHA1(5b244e9a51304318fa0c03eb7365b3c12627d19b) )
- ROM_REGION32_BE( 0x100000, "user1", 0 )
+ ROM_REGION32_BE( 0x100000, "user1", 0 ) /* Program roms are type 27C020 */
/*
-Note: If you set the dipswitch to service mode and reset the game within Mame.
- All 4 program ROMs fail the checksum code... IE: they show in red
- instead of green. But, the listed checksums on the screen match the
- checksums printed on the ROM labels... this seems wierd to me.
- However, this has been verified to happen on a real PCB
+Note: With this version, the program roms are twice the size of those found on all other Police Trainer sets. Like the set listed below,
+ if you set the dipswitch to service mode and reset the game within Mame. All 4 program ROMs fail the checksum code and the listed
+ checksums on the screen match the set below. IE: U110=556D, U111=E5F1, U112=974C & U113=CB73
+
+ However, if you check the Diagnostics screen, the program rom checksum is 6819480C which is different then the set below. So it
+ looks like it's checking the extra code. The roms do not contain identical halves, so it's unknown what the "new" data is or does.
- There was a PCB on eBay that used mask roms for the program roms with the following checksum
- values printed on the labels
+ This set has also been found using mask roms for the program roms which would indicate it was the final version.
+*/
+ ROM_LOAD32_BYTE( "pt-av13.u113", 0x00000, 0x40000, CRC(909c052d) SHA1(23bd4849261ee5cc2414a4043ee929ccf1bd6806) ) /* Checksum printed on label FB46 */
+ ROM_LOAD32_BYTE( "pt-av13.u112", 0x00001, 0x40000, CRC(f9dc9ca8) SHA1(52de7bc8c9aa7834d953b9f9e2a65e06f8042f0a) ) /* Checksum printed on label 201D */
+ ROM_LOAD32_BYTE( "pt-av13.u111", 0x00002, 0x40000, CRC(8c4f3a64) SHA1(4953e6fc26bae7d6e7c7230f4ca76e3f5032af14) ) /* Checksum printed on label F343 */
+ ROM_LOAD32_BYTE( "pt-av13.u110", 0x00003, 0x40000, CRC(738a8277) SHA1(423a9bcecb82959f38ae79a0728d72eb13ed93b3) ) /* Checksum printed on label 050C */
- U110 050C
- u111 F343
- U112 201D
- U113 FB46
+ ROM_REGION( 0x600000, "bsmt", 0 )
+ ROM_LOAD( "pt-u160.bin", 0x000000, 0x100000, CRC(f267f813) SHA1(ae58507947fe2e9701b5df46565fd9908e2f9d77) )
+ ROM_RELOAD( 0x3f8000, 0x100000 )
+ ROM_LOAD( "pt-u162.bin", 0x100000, 0x100000, CRC(75fe850e) SHA1(ab8cf24ae6e5cf80f6a9a34e46f2b1596879643b) )
+ ROM_RELOAD( 0x4f8000, 0x100000 )
+ROM_END
- These are different then the current set and might have the checksum test corrected.
+ROM_START( plctr13b ) /* Rev 0.5B PCB , unknown program rom date Actual version is V1.3B */
+ ROM_REGION( 0x400000, "gfx1", ROMREGION_ERASE00 )
+ ROM_LOAD16_BYTE( "pt-u121.bin", 0x000000, 0x100000, CRC(56b0b00a) SHA1(4034fe373a61f756f4813f0c20b1cf05e4338059) )
+ ROM_LOAD16_BYTE( "pt-u120.bin", 0x000001, 0x100000, CRC(ca664142) SHA1(2727ecb9287b4ed30088e017bb6b8763dfb75b2f) )
+ ROM_LOAD16_BYTE( "pt-u125.bin", 0x200000, 0x100000, CRC(e9ccf3a0) SHA1(b3fd8c094f76ace4cf403c3d0f6bd6c5d8db7d6a) )
+ ROM_LOAD16_BYTE( "pt-u124.bin", 0x200001, 0x100000, CRC(f4acf921) SHA1(5b244e9a51304318fa0c03eb7365b3c12627d19b) )
+
+ ROM_REGION32_BE( 0x100000, "user1", 0 ) /* Program roms are type 27C010 */
+/*
+Note: If you set the dipswitch to service mode and reset the game within Mame. All 4 program ROMs fail the checksum code, IE: they
+ show in red instead of green. But, the listed checksums on the screen match the checksums printed on the ROM labels. However,
+ this has been verified to happen on a real PCB
+
+ The program rom checksum in the diagnostic screen is 17551773
*/
- ROM_LOAD32_BYTE( "ptb-u113.v13", 0x00000, 0x20000, CRC(d636c00d) SHA1(ef989eb85b51a64ca640297c1286514c8d7f8f76) )
- ROM_LOAD32_BYTE( "ptb-u112.v13", 0x00001, 0x20000, CRC(86f0497e) SHA1(d177023f7cb2e01de60ef072212836dc94759c1a) )
- ROM_LOAD32_BYTE( "ptb-u111.v13", 0x00002, 0x20000, CRC(39e96d6a) SHA1(efe6ffe70432b94c98f3d7247408a6d2f6f9e33d) )
- ROM_LOAD32_BYTE( "ptb-u110.v13", 0x00003, 0x20000, CRC(d7e6f4cb) SHA1(9dffe4937bc5cf47d870f06ae0dced362cd2dd66) )
+ ROM_LOAD32_BYTE( "ptb-u113.v13", 0x00000, 0x20000, CRC(d636c00d) SHA1(ef989eb85b51a64ca640297c1286514c8d7f8f76) ) /* Checksum printed on label CB73 */
+ ROM_LOAD32_BYTE( "ptb-u112.v13", 0x00001, 0x20000, CRC(86f0497e) SHA1(d177023f7cb2e01de60ef072212836dc94759c1a) ) /* Checksum printed on label 974C */
+ ROM_LOAD32_BYTE( "ptb-u111.v13", 0x00002, 0x20000, CRC(39e96d6a) SHA1(efe6ffe70432b94c98f3d7247408a6d2f6f9e33d) ) /* Checksum printed on label E5F1 */
+ ROM_LOAD32_BYTE( "ptb-u110.v13", 0x00003, 0x20000, CRC(d7e6f4cb) SHA1(9dffe4937bc5cf47d870f06ae0dced362cd2dd66) ) /* Checksum printed on label 556D */
ROM_REGION( 0x600000, "bsmt", 0 )
ROM_LOAD( "pt-u160.bin", 0x000000, 0x100000, CRC(f267f813) SHA1(ae58507947fe2e9701b5df46565fd9908e2f9d77) )
@@ -715,6 +735,7 @@ GAME( 1996, policetr, 0, policetr, policetr, policetr, ROT0, "P & P Marke
GAME( 1996, polict11, policetr, policetr, polict10, policetr, ROT0, "P & P Marketing", "Police Trainer (Rev 1.1)", 0 )
GAME( 1996, polict10, policetr, policetr, polict10, policetr, ROT0, "P & P Marketing", "Police Trainer (Rev 1.0)", 0 )
+GAME( 1996, plctr13a, policetr, sshooter, policetr, plctr13b, ROT0, "P & P Marketing", "Police Trainer (Rev 1.3B Newer)", 0 )
GAME( 1996, plctr13b, policetr, sshooter, policetr, plctr13b, ROT0, "P & P Marketing", "Police Trainer (Rev 1.3B)", 0 )
GAME( 1998, sshooter, 0, sshooter, policetr, sshooter, ROT0, "P & P Marketing", "Sharpshooter (Rev 1.7)", 0 )
GAME( 1998, sshoot12, sshooter, sshooter, sshoot11, sshoot12, ROT0, "P & P Marketing", "Sharpshooter (Rev 1.2)", 0 )